==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CustomMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescriptionMetadata } from "./GetTileImageUriArgsDescriptionMetadata";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { CustomMapImageryDescription } from "./CustomMapImageryDescription";
/**
 * @hidden
 */
var CustomMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomMapImageryDescriptionMetadata, _super);
    function CustomMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomMapImageryDescriptionMetadata.b = function (a) {
        if (CustomMapImageryDescriptionMetadata.a == null) {
            CustomMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomMapImageryDescriptionMetadata.c(CustomMapImageryDescriptionMetadata.a);
        }
        if (a.g(CustomMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.s(CustomMapImageryDescriptionMetadata.a);
        GetTileImageUriArgsDescriptionMetadata.d(a);
    };
    CustomMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("GetTileImageUriRef", "EventRef::getTileImageUri");
    };
    CustomMapImageryDescriptionMetadata.d = function (a) {
        CustomMapImageryDescriptionMetadata.b(a);
        a.u("CustomMapImagery", function () { return new CustomMapImageryDescription(); });
        a.t("CustomMapImagery", CustomMapImageryDescriptionMetadata.a);
    };
    CustomMapImageryDescriptionMetadata.$t = markType(CustomMapImageryDescriptionMetadata, 'CustomMapImageryDescriptionMetadata');
    CustomMapImageryDescriptionMetadata.a = null;
    return CustomMapImageryDescriptionMetadata;
}(Base));
export { CustomMapImageryDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CustomMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescriptionMetadata } from "./GetTileImageUriArgsDescriptionMetadata";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { CustomMapImageryDescription } from "./CustomMapImageryDescription";
/**
 * @hidden
 */
var CustomMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomMapImageryDescriptionMetadata, _super);
    function CustomMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomMapImageryDescriptionMetadata.b = function (a) {
        if (CustomMapImageryDescriptionMetadata.a == null) {
            CustomMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomMapImageryDescriptionMetadata.c(CustomMapImageryDescriptionMetadata.a);
        }
        if (a.j(CustomMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.y(CustomMapImageryDescriptionMetadata.a);
        GetTileImageUriArgsDescriptionMetadata.d(a);
    };
    CustomMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("GetTileImageUriRef", "EventRef::getTileImageUri");
    };
    CustomMapImageryDescriptionMetadata.d = function (a) {
        CustomMapImageryDescriptionMetadata.b(a);
        a.aa("CustomMapImagery", function () { return new CustomMapImageryDescription(); });
        a.z("CustomMapImagery", CustomMapImageryDescriptionMetadata.a);
    };
    CustomMapImageryDescriptionMetadata.$t = markType(CustomMapImageryDescriptionMetadata, 'CustomMapImageryDescriptionMetadata');
    CustomMapImageryDescriptionMetadata.a = null;
    return CustomMapImageryDescriptionMetadata;
}(Base));
export { CustomMapImageryDescriptionMetadata };
